@@ -15,6 +15,8 @@
 
 package com.clustercontrol.performanceMGR.ejb.bmp;
 
+import java.io.File;
+import java.io.FileInputStream;
 import java.rmi.RemoteException;
 import java.text.ParseException;
 import java.util.ArrayList;
@@ -22,6 +24,7 @@ import java.util.Collection;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Properties;
 
 import javax.ejb.CreateException;
 import javax.ejb.EJBException;
@@ -694,11 +697,14 @@ public class CollectorBean implements EntityBean {
 			cronString = "0 */10 * * * ? *";
 			
 			if(interval < 60){  // 秒単位の場合
-				cronString = "*/" + interval + " * * * * ? *";
+				int delayTimeUnder1min = QuartzConstant.getDelayTimeUnder1min();
+				cronString = delayTimeUnder1min + "/" + interval + " * * * * ? *";
 			} else if (60 <= interval && interval < 3600){  // 分単位の場合
-				cronString = "0 */" + interval/60 + " * * * ? *";
+				int delayTimeOver1min = QuartzConstant.getDelayTimeOver1min();
+				cronString = delayTimeOver1min + " */" + interval/60 + " * * * ? *";
 			} else if (3600 <= interval){  // 時間単位の場合
-				cronString = "0 0 */" + interval/3600 + " * * ? *";
+				int delayTimeOver1min = QuartzConstant.getDelayTimeOver1min();
+				cronString = delayTimeOver1min + " 0 */" + interval/3600 + " * * ? *";
 			} else {
 				String message = "サポートしていない収集間隔です";
 				throw new EJBException(message);
